Crate jobberdb

source ·
Library bundle jobberdb.

See module for the application which uses it.

Modules

  • Check a job before insertion into job database.
  • Commands that jobber can process.
  • Configuration of a jobber database.
  • Temporal context of a jobber run.
  • Date and time
  • Duration in time
  • Errors & Warnings
  • CSV Export
  • Formatting functions for job properties.
  • A portion of work called job.
  • An indexed list of jobs which have been extracted from the Jobs database
  • Jobber’s database.
  • Operations that can be processed at a jobber database.
  • Partial date and time like it is entered by the user.
  • Positions within the database.
  • What jobber needs.
  • Temporal or positional range of jobs within the database.
  • Calendar report
  • Set of job tags.
  • Static global tag register :/ to manage colorization of tags.