pub enum Check {
Overlaps,
UnknownTags,
ConfirmDeletion,
}Expand description
Selectable checks
Variants
Overlaps
Emit Warning::Overlaps if job would overlap another in time.
UnknownTags
Emit Warning::UnknownTags if any tags of the new job are unknown within the database.
ConfirmDeletion
Emit Warning::ConfirmDeletion if a job is about to be deleted.
This check is done outside of Checks.