pub struct Configuration {
pub base: Properties,
pub tags: HashMap<String, Properties>,
}Expand description
Configuration of a jobber database.
Fields
base: PropertiesConfiguration used when no tag related configuration fit
Configuration by tag
Implementations
Sourceimpl Configuration
impl Configuration
Sourcepub fn set(&mut self, tags: &Option<TagSet>, update: &Properties) -> bool
pub fn set(&mut self, tags: &Option<TagSet>, update: &Properties) -> bool
Partially overwrite properties of configurations which match the given tags.
Sourcepub fn get_and_why(&self, tags: &TagSet) -> (Option<String>, &Properties)
pub fn get_and_why(&self, tags: &TagSet) -> (Option<String>, &Properties)
get properties for the given tags and additionally return which tag was relevant
Sourcepub fn get(&self, tags: &TagSet) -> &Properties
pub fn get(&self, tags: &TagSet) -> &Properties
get properties for the given tags
Sourcepub fn get_checked(&self, tags: &TagSet) -> Result<&Properties, Error>
pub fn get_checked(&self, tags: &TagSet) -> Result<&Properties, Error>
get properties for the given tags and also check tag configuration consistency