pub struct JobListOwned {
pub configuration: Configuration,
/* private fields */
}Expand description
List of jobs with index extracted from database list.
This is needed to let Error contain job lists even if the database is gone already.
Fields
configuration: ConfigurationCopy of the configuration of the original Jobs database.
Implementations