pub enum Operation {
None,
Intro,
Push(usize, Job),
Modify(usize, Job),
Delete(Positions),
Import(String, usize, TagSet),
Configure(Option<TagSet>, Properties),
List(Positions, Range, Option<TagSet>),
Report(Positions, Range, Option<TagSet>),
ExportCSV(Positions, Range, Option<TagSet>, Columns),
ListTags(TagSet),
ShowConfiguration(Configuration),
}Expand description
Catches what to change the jobs within the database.
Variants
None
No operation
Intro
No change
Push(usize, Job)
Push a new Job into database.
Modify(usize, Job)
Change an existing Job at index usize into database but return error if message is missing.
Delete(Positions)
Remove jobs from
Import(String, usize, TagSet)
Import file
Configure(Option<TagSet>, Properties)
Change configuration
List(Positions, Range, Option<TagSet>)
List jobs
Report(Positions, Range, Option<TagSet>)
Report jobs
ExportCSV(Positions, Range, Option<TagSet>, Columns)
Export jobs
ListTags(TagSet)
List all available tags.
ShowConfiguration(Configuration)
Show the database configuration.
Implementations