PartialDateTime

Enum PartialDateTime 

pub enum PartialDateTime {
    None,
    HM {
        hour: u32,
        minute: u32,
    },
    MD {
        month: u32,
        day: u32,
    },
    YMDHM {
        year: i32,
        month: u32,
        day: u32,
        hour: u32,
        minute: u32,
    },
    MDHM {
        month: u32,
        day: u32,
        hour: u32,
        minute: u32,
    },
    YMD {
        year: i32,
        month: u32,
        day: u32,
    },
}
Partial date and time in different flavors.

Variants



None

None



HM

Hour and minute without date

Fields

hour: u32
minute: u32


MD

Month and day without year and time

Fields

month: u32
day: u32


YMDHM

Complete date and time.

Fields

year: i32
month: u32
day: u32
hour: u32
minute: u32


MDHM

Date and time without year.

Fields

month: u32
day: u32
hour: u32
minute: u32


YMD

Complete date without time.

Fields

year: i32
month: u32
day: u32

Implementations

Source

impl PartialDateTime

pub fn parse(dt: Option<String>) -> Result<Self, Error>

Parse a partial date from optional string.

pub fn parse_opt(dt: Option<String>) -> Self

Parse optional partial date from optional string.

pub fn or(self, other: Self) -> Self

Take self and if this is None return other.

pub fn into(self, base: DateTime) -> DateTime

Convert partial date and time into date and time by enriching it with data from base.