pub enum Range {
None,
All,
Count(usize),
At(Vec<usize>),
PositionRange(usize, usize),
FromPosition(usize),
Day(Date),
TimeRange(DateTime, DateTime),
Since(DateTime),
}Expand description
Descriptor of temporal or positional range of jobs within the database.
Variants
None
None.
All
All.
Count(usize)
Last N jobs .
At(Vec<usize>)
At given positions.
PositionRange(usize, usize)
From position to position
FromPosition(usize)
From position to the end.
Day(Date)
All at a specified day
TimeRange(DateTime, DateTime)
All jobs overlapping the given time range.
Since(DateTime)
All jobs which overlap the time since a specified time.
Implementations